Package: MGBT
Type: Package
Title: Multiple Grubbs-Beck Low-Outlier Test
Version: 1.1.6
Depends: R (>= 4.0.0)
Suggests: dataRetrieval, lmomco
Date: 2026-05-21
Authors@R: c(person(c("William", "H."), "Asquith",
                    role = c("aut", "cre"),
                    email = "wasquith@usgs.gov",
		                  comment = c(ORCID = "0000-0002-7400-1861")),
             person(c("John", "F."), "England",
                    role = c("aut", "ctb"),
                    comment = c(ORCID = "0000-0001-5563-6274")),
             person(c("George", "R."),"Herrmann",
                    role = "ctb",
                    comment = c(ORCID = "0000-0003-3829-5580")))
Description: Compute the multiple Grubbs-Beck low-outlier test on positively distributed
 data and utilities for noninterpretive U.S. Geological Survey annual peak-streamflow
 data processing discussed in Cohn et al. (2013) and
 England et al. (2017) <doi:10.3133/tm4B5>. Other utilities for working with peak streamflow
 are provided.
Maintainer: William H. Asquith <wasquith@usgs.gov>
License: CC0
Copyright: This software is in the public domain because it contains
        materials that originally came from the United States
        Geological Survey, an agency of the United States Department of
        Interior. For more information, see the official USGS copyright
        policy at
        https://www.usgs.gov/information-policies-and-instructions/copyrights-and-credits
NeedsCompilation: no
URL: https://doi.org/10.5066/P9CW9EF0
Packaged: 2026-05-26 21:54:54 UTC; wasquith
Author: William H. Asquith [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7400-1861>),
  John F. England [aut, ctb] (ORCID:
    <https://orcid.org/0000-0001-5563-6274>),
  George R. Herrmann [ctb] (ORCID:
    <https://orcid.org/0000-0003-3829-5580>)
Repository: CRAN
Date/Publication: 2026-05-27 05:10:10 UTC
Built: R 4.6.0; ; 2026-05-27 05:22:15 UTC; unix
