importFrom("stats", "aggregate", "dnorm", "integrate", "pnorm", "pt",
                    "qbeta", "qnorm", "runif", "uniroot", "var")
importFrom("stats", "complete.cases")
importFrom("graphics", "plot", "points", "lines", "rug", "text")
importFrom("graphics", "axTicks", "axis", "legend", "mtext", "par", "polygon")
importFrom("grDevices", "grey", "dev.off", "pdf")
importFrom("utils", "write.table")
#-----------------------------------------------
# Following is not explicitly needed because Suggests: lmomco is used
# and not Depends:
#importFrom("lmomco", "add.log.axis", "f2flo", "lmoms", "pp",
#                     "parpe3", "quape3", "T2prob", "x2xlo")
#-----------------------------------------------
export(ASlo)
export(BLlo)
export(critK10)
export(CondMomsZ)
export(CondMomsChi2)
export(CritK)
export(EMS)
export(gtmoms)
export(GGBK)
export(jointPeaks)
export(RthOrderPValueOrthoT)
export(MGBT)
export(MGBT17c)
export(MGBT17c.verb)
export(MGBTcohn2016)
export(MGBTcohn2013)
export(MGBTnb)
export(MGBTcohn2011)
export(peta)
export(RSlo)
export(V)
export(VMS)
export(makeWaterYear)
export(peakTMtoHRS)
export(plotFFQevol)
export(plotPeaks)
export(plotPeaks_batch)
export(ratioPeakMax1Day)
export(readNWISwatstore)
export(splitPeakCodes)
