# README (path ./MGBT/inst/www/README.md)

#### Author:           William H. Asquith
#### Point of contact: William H. Asquith (wasquith@usgs.gov)

***
***

This README file describes the contents of the above path. This directory is to contain
various files to augment the Internet viewing of the code base as marked up by GitHub,
GitLab, or other markup resources. The avatar for the project itselt is contained herein
along with example graphics as needed for the README file in the home directory.
